==> geeklog-1.4.1.tbz: www/data/geeklog/plugins/staticpages/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the estonian language page for the Geeklog Static Page Plug-in
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

###############################################################################
# Array Format: 
# $LANGXX[YY]:	$LANG - variable name
#		  	XX - file id number
#			YY - phrase id number
###############################################################################


$LANG_STATIC= array(
    'newpage' => 'Uus leht',
    'adminhome' => 'Admin avaleht',
    'staticpages' => 'Staatilised lehed',
    'staticpageeditor' => 'Staatiliste lehtede toimetaja',
    'writtenby' => 'Kirjutas',
    'date' => 'Uuendatud',
    'title' => 'Tiitel',
    'content' => 'Sisu',
    'hits' => 'Klikke',
    'staticpagelist' => 'Staatiliste lehtede nimekiri',
    'url' => 'URL',
    'edit' => 'Toimeta',
    'lastupdated' => 'Uuendatud',
    'pageformat' => 'Lehe kujundus',
    'leftrightblocks' => 'vasak- ja paremblokid',
    'blankpage' => 'thi leht',
    'noblocks' => 'blokkideta',
    'leftblocks' => 'Vasakblokid',
    'addtomenu' => 'Lisa mensse',
    'label' => 'Silt',
    'nopages' => 'Ssteemis pole veel staatilisi lehti',
    'save' => 'salvesta',
    'preview' => 'eelvaade',
    'delete' => 'kustuta',
    'cancel' => 'thista',
    'access_denied' => 'Ligips tkestatud',
    'access_denied_msg' => 'Sa proovisid ilma vastavate igusteta ligi pseda hele staatiliste lehtede administreerimislehtedest. Pane thele, et kik sellised katsed logitakse.',
    'all_html_allowed' => 'Kogu HTML on lubatud',
    'results' => 'Staatiliste lehtede tulemus',
    'author' => 'Autor',
    'no_title_or_content' => 'Sa pead titma vhemalt <b>tiitli</b> ja <b>sisu</b> vljad.',
    'no_such_page_anon' => 'Palun logi sisse...',
    'no_page_access_msg' => "Phjuseks vib olla, et sa pole veel sisse loginud vi pole veel {$_CONF['site_name']} lehe registreerunud kasutaja. Palun <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> registreeru {$_CONF['site_name']} lehe kasutajaks.</a> Registreerumine annab sulle kik lehe liikme ligipsuigused.",
    'php_msg' => 'PHP: ',
    'php_warn' => 'Hoiatus! Selle valiku sissellitamisel kivitatakse lehel olevad PHP ksud. Kasuta ettevaatusega!',
    'exit_msg' => 'Tagastuse tp',
    'exit_info' => 'Kasuta logimismrkuste jaoks. Tavalise lehe kasutus- ja turvateadete jaoks jta mrge tegemata.',
    'deny_msg' => 'Ligips sellele lehele on tkestatud. Vimalik, et  see leht on kas kustutatud vi mbernimetatud vi pole sul piisavalt igusi seda lehte nha.',
    'stats_headline' => 'Staatiliste lehtede top 10',
    'stats_page_title' => 'Lehe tiitel',
    'stats_hits' => 'Klikke',
    'stats_no_hits' => 'Nib, et saidil pole htegi staatilist lehte vi mitte keegi pole neid vaadanud.',
    'id' => 'ID',
    'duplicate_id' => 'Sisestatud staatilise lehe ID on juba kasutuses. Vali teine ID.',
    'instructions' => 'Staatilise lehe toimetamiseks vi kustutamiseks klpsa allpool staatilise lehe juures olevat toimetamisikooni. Staatilise lehe vaatamiseks klpsa selle tiitlil. Uue loomiseks klpsa "Tee uus" lal. Olemasolevast staatilisest lehest koopia tegemiseks klpsa kopeerimisikooni.',
    'centerblock' => 'Keskblokk: ',
    'centerblock_msg' => 'Kui mrgitud, nidatakse seda staatilist lehte indeks lehel keskblokina.',
    'topic' => 'Rubriik: ',
    'position' => 'Asukoht: ',
    'all_topics' => 'Kik',
    'no_topic' => 'Ainult avaleht',
    'position_top' => 'Lehe laservas',
    'position_feat' => 'Peale pealugu',
    'position_bottom' => 'Lehe allservas',
    'position_entire' => 'Kogu leht',
    'head_centerblock' => 'Keskblokk',
    'centerblock_no' => 'Ei',
    'centerblock_top' => 'lal',
    'centerblock_feat' => 'Pealugu',
    'centerblock_bottom' => 'All',
    'centerblock_entire' => 'Kogu',
    'inblock_msg' => 'Blokina:',
    'inblock_info' => 'Paiguta staatiline leht blokki.',
    'title_edit' => 'Toimeta lehte',
    'title_copy' => 'Tee lehest koopia',
    'title_display' => 'Nita leht',
    'select_php_none' => 'ra kivita PHP',
    'select_php_return' => 'kivita PHP (return)',
    'select_php_free' => 'kivita PHP',
    'php_not_activated' => 'Staatilistel lehtedel pole PHP kasutamine sisse llitatud. Tpsemat infot palun vaata <a href="' . $_CONF['site_url'] . '/docs/staticpages.html#php">dokumentatsioonist.</a>',
    'printable_format' => 'Prinditaval kujul',
    'edit' => 'Toimeta',
    'copy' => 'Koopia',
    'limit_results' => 'Piira tulemused',
    'search' => 'Otsi',
    'submit' => 'Sisesta'
);

?>

==> geeklog-1.5.0.tbz: www/data/geeklog/plugins/staticpages/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the estonian language page for the Geeklog Static Page Plug-in
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format: 
# $LANGXX[YY]:	$LANG - variable name
#		  	XX - file id number
#			YY - phrase id number
###############################################################################


$LANG_STATIC= array(
    'newpage' => 'Uus leht',
    'adminhome' => 'Admin avaleht',
    'staticpages' => 'Staatilised lehed',
    'staticpageeditor' => 'Staatiliste lehtede toimetaja',
    'writtenby' => 'Kirjutas',
    'date' => 'Uuendatud',
    'title' => 'Tiitel',
    'content' => 'Sisu',
    'hits' => 'Klikke',
    'staticpagelist' => 'Staatiliste lehtede nimekiri',
    'url' => 'URL',
    'edit' => 'Toimeta',
    'lastupdated' => 'Uuendatud',
    'pageformat' => 'Lehe kujundus',
    'leftrightblocks' => 'vasak- ja paremblokid',
    'blankpage' => 'thi leht',
    'noblocks' => 'blokkideta',
    'leftblocks' => 'Vasakblokid',
    'addtomenu' => 'Lisa mensse',
    'label' => 'Silt',
    'nopages' => 'Ssteemis pole veel staatilisi lehti',
    'save' => 'salvesta',
    'preview' => 'eelvaade',
    'delete' => 'kustuta',
    'cancel' => 'thista',
    'access_denied' => 'Ligips tkestatud',
    'access_denied_msg' => 'Sa proovisid ilma vastavate igusteta ligi pseda hele staatiliste lehtede administreerimislehtedest. Pane thele, et kik sellised katsed logitakse.',
    'all_html_allowed' => 'Kogu HTML on lubatud',
    'results' => 'Staatiliste lehtede tulemus',
    'author' => 'Autor',
    'no_title_or_content' => 'Sa pead titma vhemalt <b>tiitli</b> ja <b>sisu</b> vljad.',
    'no_such_page_anon' => 'Palun logi sisse...',
    'no_page_access_msg' => "Phjuseks vib olla, et sa pole veel sisse loginud vi pole veel {$_CONF['site_name']} lehe registreerunud kasutaja. Palun <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> registreeru {$_CONF['site_name']} lehe kasutajaks.</a> Registreerumine annab sulle kik lehe liikme ligipsuigused.",
    'php_msg' => 'PHP: ',
    'php_warn' => 'Hoiatus! Selle valiku sissellitamisel kivitatakse lehel olevad PHP ksud. Kasuta ettevaatusega!',
    'exit_msg' => 'Tagastuse tp',
    'exit_info' => 'Kasuta logimismrkuste jaoks. Tavalise lehe kasutus- ja turvateadete jaoks jta mrge tegemata.',
    'deny_msg' => 'Ligips sellele lehele on tkestatud. Vimalik, et  see leht on kas kustutatud vi mbernimetatud vi pole sul piisavalt igusi.',
    'stats_headline' => 'Staatiliste lehtede top 10',
    'stats_page_title' => 'Lehe tiitel',
    'stats_hits' => 'Klikke',
    'stats_no_hits' => 'Nib, et saidil pole htegi staatilist lehte vi mitte keegi pole neid vaadanud.',
    'id' => 'ID',
    'duplicate_id' => 'Sisestatud staatilise lehe ID on juba kasutuses. Vali teine ID.',
    'instructions' => 'Staatilise lehe toimetamiseks vi kustutamiseks klpsa allpool staatilise lehe juures olevat toimetamisikooni. Staatilise lehe vaatamiseks klpsa selle tiitlil. Uue loomiseks klpsa "Tee uus" lal. Olemasolevast staatilisest lehest koopia tegemiseks klpsa kopeerimisikooni.',
    'centerblock' => 'Keskblokk: ',
    'centerblock_msg' => 'Kui mrgitud, nidatakse seda staatilist lehte indeks lehel keskblokina.',
    'topic' => 'Rubriik: ',
    'position' => 'Asukoht: ',
    'all_topics' => 'Kik',
    'no_topic' => 'Ainult avaleht',
    'position_top' => 'Lehe laservas',
    'position_feat' => 'Peale pealugu',
    'position_bottom' => 'Lehe allservas',
    'position_entire' => 'Kogu leht',
    'head_centerblock' => 'Keskblokk',
    'centerblock_no' => 'Ei',
    'centerblock_top' => 'lal',
    'centerblock_feat' => 'Pealugu',
    'centerblock_bottom' => 'All',
    'centerblock_entire' => 'Kogu',
    'inblock_msg' => 'Blokina:',
    'inblock_info' => 'Paiguta staatiline leht blokki.',
    'title_edit' => 'Toimeta lehte',
    'title_copy' => 'Tee lehest koopia',
    'title_display' => 'Nita leht',
    'select_php_none' => 'ra kivita PHP',
    'select_php_return' => 'kivita PHP (return)',
    'select_php_free' => 'kivita PHP',
    'php_not_activated' => 'Staatilistel lehtedel pole PHP kasutamine sisse llitatud. Tpsemat infot palun vaata <a href="' . $_CONF['site_url'] . '/docs/staticpages.html#php">dokumentatsioonist.</a>',
    'printable_format' => 'Prinditaval kujul',
    'edit' => 'Toimeta',
    'copy' => 'Koopia',
    'limit_results' => 'Piira tulemused',
    'search' => 'Otsi',
    'submit' => 'Sisesta'
);

// Messages for the plugin upgrade
$PLG_staticpages_MESSAGE3001 = 'Plugina uuendamine pole toetatud.';
$PLG_staticpages_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['staticpages'] = array(
    'label' => 'Staatilised lehed',
    'title' => 'Staatiliste lehtede hlestamine'
);

$LANG_confignames['staticpages'] = array(
    'allow_php' => 'Luba PHP?',
    'sort_by' => 'Keskblokkide sorteerimisalus',
    'sort_menu_by' => 'Menelementide sorteerimisalus',
    'delete_pages' => 'Kustuta lehed, omanikuks?',
    'in_block' => 'Paiguta lehed blokki?',
    'show_hits' => 'Nita klike?',
    'show_date' => 'Nita aega?',
    'filter_html' => 'Filtreeri HTML-i?',
    'censor' => 'Tsenseeri sisu?',
    'default_permissions' => 'Lehe vaikimisi igused',
    'aftersave' => 'Prast lehe salvestamist',
    'atom_max_items' => 'Maks. lehti veebiteenuste limes'
);

$LANG_configsubgroups['staticpages'] = array(
    'sg_main' => 'Peaseaded'
);

$LANG_fs['staticpages'] = array(
    'fs_main' => 'Staatiliste  lehtede peaseadistused',
    'fs_permissions' => 'Vaikimisi igused'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['staticpages'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => TRUE, 'False' => FALSE),
    2 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title'),
    3 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title', 'Label' => 'label'),
    9 => array('Forward to page' => 'item', 'Display List' => 'list', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
);


?>
